.. _fluent_pages.adminui:

fluent_pages.adminui
====================

.. automodule:: fluent_pages.adminui

The ``PageAdmin`` class
-----------------------

.. autoclass:: fluent_pages.adminui.PageAdmin
   :members:
   :show-inheritance:

.. autoclass:: fluent_pages.adminui.DefaultPageChildAdmin
   :members:
   :show-inheritance:


The ``PageAdminForm`` class
---------------------------

.. autoclass:: fluent_pages.adminui.PageAdminForm
   :members:


The ``HtmlPageAdmin`` class
---------------------------

.. autoclass:: fluent_pages.adminui.HtmlPageAdmin
   :members:
   :show-inheritance:
